@@ -6,6 +6,7 @@ import (
 	"strings"
 	"time"
 
+	"github.com/openshift/cluster-logging-operator/pkg/logger"
 	"github.com/openshift/cluster-logging-operator/pkg/utils"
 	"github.com/sirupsen/logrus"
 	"k8s.io/apimachinery/pkg/api/errors"
@@ -13,6 +14,7 @@ import (
 	"k8s.io/apimachinery/pkg/util/wait"
 	"k8s.io/client-go/util/retry"
 
+	configv1 "github.com/openshift/api/config/v1"
 	logging "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
 	apps "k8s.io/api/apps/v1"
 	core "k8s.io/api/core/v1"
@@ -35,20 +37,16 @@ var (
 var serviceAccountLogCollectorUID types.UID
 
 //CreateOrUpdateCollection component of the cluster
-func (clusterRequest *ClusterLoggingRequest) CreateOrUpdateCollection() (err error) {
+func (clusterRequest *ClusterLoggingRequest) CreateOrUpdateCollection(proxyConfig *configv1.Proxy) (err error) {
 	cluster := clusterRequest.cluster
-
-	//Bug 1751339: Drop rsyslog support
-	if cluster.Spec.Collection.Logs.Type != logging.LogCollectionTypeFluentd {
-		logrus.Infof("Unsupported log collector: %v", cluster.Spec.Collection.Logs.Type)
-		return nil
-	}
+	collectorConfig := ""
+	collectorConfHash := ""
 
 	var collectorServiceAccount *core.ServiceAccount
 
 	// there is no easier way to check this in golang without writing a helper function
 	// TODO: write a helper function to validate Type is a valid option for common setup or tear down
-	if cluster.Spec.Collection.Logs.Type == logging.LogCollectionTypeFluentd || cluster.Spec.Collection.Logs.Type == logging.LogCollectionTypeRsyslog {
+	if cluster.Spec.Collection != nil && cluster.Spec.Collection.Logs.Type == logging.LogCollectionTypeFluentd {
 		if err = clusterRequest.createOrUpdateCollectionPriorityClass(); err != nil {
 			return
 		}
@@ -56,10 +54,12 @@ func (clusterRequest *ClusterLoggingRequest) CreateOrUpdateCollection() (err err
 		if collectorServiceAccount, err = clusterRequest.createOrUpdateCollectorServiceAccount(); err != nil {
 			return
 		}
-	}
-
-	if cluster.Spec.Collection.Logs.Type == logging.LogCollectionTypeFluentd {
 
+		if collectorConfig, err = clusterRequest.generateCollectorConfig(); err != nil {
+			return
+		}
+		logger.Debugf("Generated collector config: %s", collectorConfig)
+		collectorConfHash = utils.CalculateMD5Hash(collectorConfig)
 		if err = clusterRequest.createOrUpdateFluentdService(); err != nil {
 			return
 		}
@@ -72,7 +72,7 @@ func (clusterRequest *ClusterLoggingRequest) CreateOrUpdateCollection() (err err
 			return
 		}
 
-		if err = clusterRequest.createOrUpdateFluentdConfigMap(); err != nil {
+		if err = clusterRequest.createOrUpdateFluentdConfigMap(collectorConfig); err != nil {
 			return
 		}
 
@@ -80,7 +80,7 @@ func (clusterRequest *ClusterLoggingRequest) CreateOrUpdateCollection() (err err
 			return
 		}
 
-		if err = clusterRequest.createOrUpdateFluentdDaemonset(); err != nil {
+		if err = clusterRequest.createOrUpdateFluentdDaemonset(collectorConfHash, proxyConfig); err != nil {
 			return
 		}
 
@@ -91,81 +91,39 @@ func (clusterRequest *ClusterLoggingRequest) CreateOrUpdateCollection() (err err
 
 		printUpdateMessage := true
 		retryErr := retry.RetryOnConflict(retry.DefaultRetry, func() error {
-			if !reflect.DeepEqual(fluentdStatus, cluster.Status.Collection.Logs.FluentdStatus) {
+			if !compareFluentdCollectorStatus(fluentdStatus, cluster.Status.Collection.Logs.FluentdStatus) {
 				if printUpdateMessage {
 					logrus.Info("Updating status of Fluentd")
 					printUpdateMessage = false
 				}
 				cluster.Status.Collection.Logs.FluentdStatus = fluentdStatus
-				return clusterRequest.Update(cluster)
+				return clusterRequest.UpdateStatus(cluster)
 			}
 			return nil
 		})
 		if retryErr != nil {
 			return fmt.Errorf("Failed to update Cluster Logging Fluentd status: %v", retryErr)
 		}
-	}
 
-	if cluster.Spec.Collection.Logs.Type == logging.LogCollectionTypeRsyslog {
-		if err = clusterRequest.createOrUpdateRsyslogService(); err != nil {
-			return
-		}
+		if collectorServiceAccount != nil {
 
-		if err = clusterRequest.createOrUpdateRsyslogServiceMonitor(); err != nil {
-			return
-		}
-
-		if err = clusterRequest.createOrUpdateRsyslogPrometheusRule(); err != nil {
-			return
-		}
-
-		if err = clusterRequest.createOrUpdateRsyslogConfigMap(); err != nil {
-			return
-		}
-
-		if err = clusterRequest.createOrUpdateRsyslogSecret(); err != nil {
-			return
-		}
-
-		if err = clusterRequest.createOrUpdateLogrotateConfigMap(); err != nil {
-			return
-		}
-
-		if err = clusterRequest.createOrUpdateRsyslogDaemonset(); err != nil {
-			return
-		}
-
-		rsyslogStatus, err := clusterRequest.getRsyslogCollectorStatus()
-		if err != nil {
-			return fmt.Errorf("Failed to get status of Rsyslog: %v", err)
-		}
-
-		printUpdateMessage := true
-		retryErr := retry.RetryOnConflict(retry.DefaultRetry, func() error {
-			if !reflect.DeepEqual(rsyslogStatus, cluster.Status.Collection.Logs.RsyslogStatus) {
-				if printUpdateMessage {
-					logrus.Info("Updating status of Rsyslog")
-					printUpdateMessage = false
-				}
-				cluster.Status.Collection.Logs.RsyslogStatus = rsyslogStatus
-				return clusterRequest.Update(cluster)
+			// remove our finalizer from the list and update it.
+			collectorServiceAccount.ObjectMeta.Finalizers = utils.RemoveString(collectorServiceAccount.ObjectMeta.Finalizers, metav1.FinalizerDeleteDependents)
+			err = clusterRequest.Create(collectorServiceAccount)
+			if err != nil && !errors.IsAlreadyExists(err) {
+				return nil
 			}
-			return nil
-		})
-		if retryErr != nil {
-			return fmt.Errorf("Failed to update Cluster Logging Rsyslog status: %v", retryErr)
 		}
-	}
+	} else {
+		if err = clusterRequest.RemoveServiceAccount("logcollector"); err != nil {
+			return
+		}
+
+		if err = clusterRequest.RemovePriorityClass(clusterLoggingPriorityClassName); err != nil {
+			return
+		}
 
-	if cluster.Spec.Collection.Logs.Type != logging.LogCollectionTypeFluentd {
 		clusterRequest.removeFluentd()
-	}
-
-	if cluster.Spec.Collection.Logs.Type != logging.LogCollectionTypeRsyslog {
-		clusterRequest.removeRsyslog()
-	}
-
-	if cluster.Spec.Collection.Logs.Type != logging.LogCollectionTypeFluentd && cluster.Spec.Collection.Logs.Type != logging.LogCollectionTypeRsyslog {
 		if err = clusterRequest.RemoveServiceAccount("logcollector"); err != nil {
 			return
 		}
@@ -174,17 +132,46 @@ func (clusterRequest *ClusterLoggingRequest) CreateOrUpdateCollection() (err err
 			return
 		}
 	}
-	if collectorServiceAccount != nil && (cluster.Spec.Collection.Logs.Type == logging.LogCollectionTypeFluentd || cluster.Spec.Collection.Logs.Type == logging.LogCollectionTypeRsyslog) {
 
-		// remove our finalizer from the list and update it.
-		collectorServiceAccount.ObjectMeta.Finalizers = utils.RemoveString(collectorServiceAccount.ObjectMeta.Finalizers, metav1.FinalizerDeleteDependents)
-		err = clusterRequest.Create(collectorServiceAccount)
-		if err != nil && !errors.IsAlreadyExists(err) {
-			return
+	return nil
+}
+
+func compareFluentdCollectorStatus(lhs, rhs logging.FluentdCollectorStatus) bool {
+	if lhs.DaemonSet != rhs.DaemonSet {
+		return false
+	}
+
+	if len(lhs.Conditions) != len(rhs.Conditions) {
+		return false
+	}
+
+	if len(lhs.Conditions) > 0 {
+		if !reflect.DeepEqual(lhs.Conditions, rhs.Conditions) {
+			return false
 		}
 	}
 
-	return nil
+	if len(lhs.Nodes) != len(rhs.Nodes) {
+		return false
+	}
+
+	if len(lhs.Nodes) > 0 {
+		if !reflect.DeepEqual(lhs.Nodes, rhs.Nodes) {
+			return false
+		}
+	}
+
+	if len(lhs.Pods) != len(rhs.Pods) {
+		return false
+	}
+
+	if len(lhs.Pods) > 0 {
+		if !reflect.DeepEqual(lhs.Pods, rhs.Pods) {
+			return false
+		}
+	}
+
+	return true
 }
 
 func (clusterRequest *ClusterLoggingRequest) createOrUpdateCollectionPriorityClass() error {
@@ -339,11 +326,24 @@ func isDaemonsetDifferent(current *apps.DaemonSet, desired *apps.DaemonSet) (*ap
 		logrus.Infof("Collector resource(s) change found, updating %q", current.Name)
 		different = true
 	}
-	if !reflect.DeepEqual(current.Spec.Template.Spec.Containers[0].Env, desired.Spec.Template.Spec.Containers[0].Env) {
+
+	if !utils.EnvValueEqual(current.Spec.Template.Spec.Containers[0].Env, desired.Spec.Template.Spec.Containers[0].Env) {
 		logrus.Infof("Collector container EnvVar change found, updating %q", current.Name)
+		logger.Debugf("Collector envvars - current: %v, desired: %v", current.Spec.Template.Spec.Containers[0].Env, desired.Spec.Template.Spec.Containers[0].Env)
 		current.Spec.Template.Spec.Containers[0].Env = desired.Spec.Template.Spec.Containers[0].Env
 		different = true
 	}
+	if !utils.PodVolumeEquivalent(current.Spec.Template.Spec.Volumes, desired.Spec.Template.Spec.Volumes) {
+		logrus.Infof("Collector volumes change found, updating %q", current.Name)
+		current.Spec.Template.Spec.Volumes = desired.Spec.Template.Spec.Volumes
+		different = true
+	}
+	if !reflect.DeepEqual(current.Spec.Template.Spec.Containers[0].VolumeMounts, desired.Spec.Template.Spec.Containers[0].VolumeMounts) {
+		logrus.Infof("Collector container volumemounts change found, updating %q", current.Name)
+		current.Spec.Template.Spec.Containers[0].VolumeMounts = desired.Spec.Template.Spec.Containers[0].VolumeMounts
+		different = true
+	}
+
 	return current, different
 }
 
